@@ -22,6 +22,10 @@
 
 #include "gdkinternals.h"
 
+#ifdef GDK_WINDOWING_WIN32
+# include "win32/gdkwin32.h"
+#endif
+
 #include <epoxy/gl.h>
 #include <math.h>
 #include <string.h>
@@ -409,6 +413,7 @@ gdk_cairo_draw_from_gl (cairo_t              *cr,
       alpha_size == 0 &&
       direct_window != NULL &&
       direct_window->current_paint.use_gl &&
+      gdk_gl_context_has_framebuffer_blit (paint_context) &&
       trivial_transform &&
       clip_region != NULL)
     {
@@ -640,6 +645,13 @@ gdk_cairo_draw_from_gl (cairo_t              *cr,
     {
       /* Software fallback */
       int major, minor, version;
+      gboolean es_read_bgra = FALSE;
+
+#ifdef GDK_WINDOWING_WIN32
+      /* on ANGLE GLES, we need to set the glReadPixel() format as GL_BGRA instead */
+      if (GDK_WIN32_IS_GL_CONTEXT(paint_context))
+        es_read_bgra = TRUE;
+#endif
 
       gdk_gl_context_get_version (paint_context, &major, &minor);
       version = major * 100 + minor;
@@ -682,7 +694,7 @@ gdk_cairo_draw_from_gl (cairo_t              *cr,
         glReadPixels (x, y, width, height, GL_BGRA, GL_UNSIGNED_INT_8_8_8_8_REV,
                       cairo_image_surface_get_data (image));
       else
-        glReadPixels (x, y, width, height, GL_RGBA, GL_UNSIGNED_BYTE,
+        glReadPixels (x, y, width, height, es_read_bgra ? GL_BGRA : GL_RGBA, GL_UNSIGNED_BYTE,
                       cairo_image_surface_get_data (image));
 
       glPixelStorei (GL_PACK_ROW_LENGTH, 0);
