@@ -24,11 +24,13 @@
 #include <gdk/gdkdisplayprivate.h>
 
 #include "gdkwindowimpl.h"
+#include "gdkwindow-quartz.h"
 #include "gdkprivate-quartz.h"
 #include "gdkglcontext-quartz.h"
 #include "gdkquartzglcontext.h"
 #include "gdkquartzscreen.h"
 #include "gdkquartzcursor.h"
+#include "gdkquartz-gtk-only.h"
 
 #include <Carbon/Carbon.h>
 #include <AvailabilityMacros.h>
@@ -2719,7 +2721,7 @@ window_is_fullscreen (GdkWindow *window)
     return ([impl->toplevel styleMask] & GDK_QUARTZ_FULLSCREEN_WINDOW) != 0;
   else
 #endif
-    return g_object_get_data (G_OBJECT (window), FULLSCREEN_DATA);
+    return g_object_get_data (G_OBJECT (window), FULLSCREEN_DATA) != NULL;
 }
 
 static void
@@ -2859,7 +2861,7 @@ _gdk_quartz_window_update_fullscreen_state (GdkWindow *window)
     {
       gboolean is_fullscreen = window_is_fullscreen (window);
       gboolean was_fullscreen = (gdk_window_get_state (window) &&
-                                 GDK_WINDOW_STATE_FULLSCREEN) != 0;
+                                 GDK_WINDOW_STATE_FULLSCREEN != 0);
 
       if (is_fullscreen != was_fullscreen)
         {
